@@ -1,6 +1,7 @@
 /*
  * CUPS destination API test program for CUPS.
  *
+ * Copyright © 2020-2024 by OpenPrinting.
  * Copyright © 2012-2018 by Apple Inc.
  *
  * Licensed under Apache License v2.0.  See the file "LICENSE" for more information.
@@ -410,7 +411,6 @@ print_file(http_t        *http,		/* I - Connection to destination */
 {
   cups_file_t	*fp;			/* File to print */
   int		job_id;			/* Job ID */
-  ipp_status_t	status;			/* Submission status */
   const char	*title;			/* Title of job */
   char		buffer[32768];		/* File buffer */
   ssize_t	bytes;			/* Bytes read/to write */
@@ -427,7 +427,7 @@ print_file(http_t        *http,		/* I - Connection to destination */
   else
     title = filename;
 
-  if ((status = cupsCreateDestJob(http, dest, dinfo, &job_id, title, num_options, options)) > IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED)
+  if (cupsCreateDestJob(http, dest, dinfo, &job_id, title, num_options, options) > IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED)
   {
     printf("Unable to create job: %s\n", cupsLastErrorString());
     cupsFileClose(fp);
@@ -454,7 +454,7 @@ print_file(http_t        *http,		/* I - Connection to destination */
 
   cupsFileClose(fp);
 
-  if ((status = cupsFinishDestDocument(http, dest, dinfo)) > IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED)
+  if (cupsFinishDestDocument(http, dest, dinfo) > IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED)
   {
     printf("Unable to send document: %s\n", cupsLastErrorString());
     return;
