@@ -1,6 +1,7 @@
 /*
  * Subscription routines for the CUPS scheduler.
  *
+ * Copyright © 2020-2024 by OpenPrinting.
  * Copyright © 2007-2019 by Apple Inc.
  * Copyright © 1997-2007 by Easy Software Products, all rights reserved.
  *
@@ -621,7 +622,7 @@ cupsdExpireSubscriptions(
   curtime = time(NULL);
   update  = 0;
 
-  cupsdLogMessage(CUPSD_LOG_INFO, "Expiring subscriptions...");
+  cupsdLogMessage(CUPSD_LOG_DEBUG, "Expiring subscriptions...");
 
   for (sub = (cupsd_subscription_t *)cupsArrayFirst(Subscriptions);
        sub;
